## Happy path 1
* greet
  - utter_greet
* query_knowledge_base
  - action_query_knowledge_base
* goodbye
  - utter_goodbye

## Happy path 2
* greet
  - utter_greet
* query_knowledge_base
  - action_query_knowledge_base
* query_knowledge_base
  - action_query_knowledge_base
* goodbye
  - utter_goodbye

## Hello
* greet
- utter_greet

## Query Knowledge Base
* query_knowledge_base
- action_query_knowledge_base

## Bye
* goodbye
- utter_goodbye

## bot challenge
* bot_challenge
  - utter_iamabot
